@@ -13,9 +13,9 @@ def main():
     from jsonstore.rest import JSONStore
     from werkzeug.serving import run_simple
 
-    options, arguments = docopt(__doc__)
-    app = JSONStore(options.database)
-    run_simple(options.ip, options.port, app)
+    arguments = docopt(__doc__)
+    app = JSONStore(arguments['--database'])
+    run_simple(arguments['--ip'], int(arguments['--port']), app)
 
 
 if __name__ == '__main__':
