@@ -90,7 +90,7 @@ class EntryManager(object):
             self._delete_entry(id_)
         return entry
 
-    def update(self, entry=None, condition=lambda old: True, **kwargs): 
+    def update(self, entry=None, old=None, condition=lambda existing: True, **kwargs): 
         """
         Conditionally update an entry.
 
@@ -122,8 +122,8 @@ class EntryManager(object):
 
         id_ = entry['__id__']
         with self.lock[id_]:
-            old = self._load_entry(id_)
-            if not condition(old):
+            existing = self._load_entry(id_)
+            if (old is not None and old != existing) or not condition(existing):
                 raise ConflictError('Pre-condition failed!')
             self._delete_entry(id_)
             self._store_entry(entry)
