@@ -1,6 +1,6 @@
 import requests
 try:
-    from requests import async
+    from grequests import async
 except:
     async = False
     import threading
